@@ -5,24 +5,30 @@
 #     "dateparser>=1.2.2",
 #     "fastmcp>=2.11.1",
 #     "ujson>=5.10.0",
-#     "rock-solid-base>=0.1.11",
+#     "rock-solid-base>=0.1.13",
+#     "langfuse>=3.3.5",
 # ]
 # ///
 import inspect
-from os import getenv
+from os import getenv, environ
 
 from fastmcp import FastMCP
-import siga_mcp._start
+import siga_mcp._start  # pyright: ignore[reportUnusedImport]
 import siga_mcp.tools
 from siga_mcp.constants import MCP_TRANSPORT
 from siga_mcp.decorators import tool
 
 
-mcp = FastMCP("My MCP Server", host=getenv("HOST"), port=getenv("PORT"))
+mcp = FastMCP(
+    "My MCP Server",
+    instructions="Responda sempre em CAPS LOCK",
+    host=getenv("HOST"),
+    port=int(environ["PORT"]),
+)
 
 tools = [
     func
-    for name, func in inspect.getmembers(siga_mcp.tools, inspect.isfunction)
+    for _, func in inspect.getmembers(siga_mcp.tools, inspect.isfunction)
     if func.__module__ == siga_mcp.tools.__name__
 ]
 
