@@ -1,9 +1,12 @@
 import calendar
+from pathlib import Path
 import re
 from datetime import datetime, timedelta
 from os import getenv
-
+from typing import Any, cast
+from msal import ConfidentialClientApplication  # pyright: ignore[reportMissingTypeStubs]
 import aiohttp
+import requests
 import ujson
 
 
@@ -12,12 +15,16 @@ from siga_mcp.constants import (
     MESES_PT,
     NUMEROS_EXTENSO,
     PERIODOS_DIA,
+    TEAMS_CLIENT_ID,
+    TEAMS_CLIENT_SECRET,
+    TEAMS_TENANT_ID,
     TEMPO_FUTURO,
     TEMPO_PASSADO,
     MCP_TRANSPORT,
     MATRICULA_USUARIO_ATUAL,
-    MATRICULAS_LIBERADAS
+    MATRICULAS_LIBERADAS,
 )
+from siga_mcp.protocols import ConfidentialClientProtocol
 from siga_mcp.xml_builder import XMLBuilder
 
 
@@ -89,6 +96,12 @@ def converter_data_siga(
     data_input = data_input.strip().lower()
     data_input = re.sub(r"\s+", " ", data_input)  # Remove espaços duplos
 
+    # Novo: rejeitar números sozinhos (ex.: "23") antes de processar os casos
+    if re.fullmatch(r"\d{1,2}", data_input):
+        raise ValueError(
+            f"Formato de data não permitido: números sozinhos ('{data_input}'). Use a data completa."
+        )
+
     # === NÚMEROS SOZINHOS (NOVO CASO) ===
     # Verifica se é apenas um número (dia do mês atual)
     padrao_numero_sozinho = re.match(r"^(\d{1,2})$", data_input.strip())
@@ -100,51 +113,21 @@ def converter_data_siga(
             raise ValueError(f"Dia inválido: {dia}. Deve estar entre 1 e 31.")
 
         try:
-            # Tentar criar a data no mês atual
+            # Criar a data no mês atual
             data_resultado = datetime(hoje.year, hoje.month, dia)
 
-            # Se a data já passou neste mês, assumir próximo mês
-            if data_resultado < hoje.replace(hour=0, minute=0, second=0, microsecond=0):
-                if hoje.month == 12:
-                    data_resultado = datetime(hoje.year + 1, 1, dia)
-                else:
-                    try:
-                        data_resultado = datetime(hoje.year, hoje.month + 1, dia)
-                    except ValueError:
-                        # Se o dia não existe no próximo mês, usar o último dia válido
-                        import calendar
-
-                        ultimo_dia = calendar.monthrange(hoje.year, hoje.month + 1)[1]
-                        data_resultado = datetime(
-                            hoje.year, hoje.month + 1, min(dia, ultimo_dia)
-                        )
-
             return data_resultado.strftime(
                 "%d/%m/%Y %H:%M:%S" if manter_horas else "%d/%m/%Y"
             )
 
         except ValueError:
-            # Se o dia não existe no mês atual, tentar próximo mês
+            # Se o dia não existe no mês atual, usar o último dia válido do mês atual
             import calendar
 
-            if hoje.month == 12:
-                # Próximo ano, janeiro
-                ultimo_dia_janeiro = calendar.monthrange(hoje.year + 1, 1)[1]
-                if dia <= ultimo_dia_janeiro:
-                    data_resultado = datetime(hoje.year + 1, 1, dia)
-                else:
-                    data_resultado = datetime(hoje.year + 1, 1, ultimo_dia_janeiro)
-            else:
-                # Próximo mês
-                ultimo_dia_proximo_mes = calendar.monthrange(hoje.year, hoje.month + 1)[
-                    1
-                ]
-                if dia <= ultimo_dia_proximo_mes:
-                    data_resultado = datetime(hoje.year, hoje.month + 1, dia)
-                else:
-                    data_resultado = datetime(
-                        hoje.year, hoje.month + 1, ultimo_dia_proximo_mes
-                    )
+            ultimo_dia_mes_atual = calendar.monthrange(hoje.year, hoje.month)[1]
+            data_resultado = datetime(
+                hoje.year, hoje.month, min(dia, ultimo_dia_mes_atual)
+            )
 
             return data_resultado.strftime(
                 "%d/%m/%Y %H:%M:%S" if manter_horas else "%d/%m/%Y"
@@ -212,7 +195,7 @@ def _processar_linguagem_natural_pt(
     # Expressões coloquiais que podem conflitar com outras palavras
     if "outro dia" in data_input:
         # Alguns dias atrás (não uma data futura)
-        data_resultado = hoje - timedelta(days=3)
+        data_resultado: datetime = hoje - timedelta(days=3)
         return data_resultado.strftime(
             "%d/%m/%Y %H:%M:%S" if manter_horas else "%d/%m/%Y"
         )
@@ -342,7 +325,7 @@ def _processar_linguagem_natural_pt(
 
     # === PERÍODOS DO DIA (verificar primeiro as expressões compostas) ===
     # Detectar frases como "hoje de manhã", "ontem à noite", etc.
-    periodos_detectados = []
+    periodos_detectados: list[str] = []
     for periodo in PERIODOS_DIA.keys():
         if periodo in data_input:
             periodos_detectados.append(periodo)
@@ -1217,7 +1200,8 @@ def verificar_permissao_acesso_matricula(matricula_desejada: str) -> bool | None
     Returns:
         bool: True se o usuário tem permissão, False caso contrário.
     """
-    if MATRICULA_USUARIO_ATUAL in MATRICULAS_LIBERADAS:
+    matricula = MATRICULA_USUARIO_ATUAL or ""
+    if matricula in MATRICULAS_LIBERADAS:
         return True
 
     if MCP_TRANSPORT == "stdio":
@@ -1226,5 +1210,88 @@ def verificar_permissao_acesso_matricula(matricula_desejada: str) -> bool | None
     return None
 
 
+def get_access_token(client_id: str, client_secret: str, tenant_id: str) -> str:
+    authority: str = f"https://login.microsoftonline.com/{tenant_id}"
+
+    scope: list[str] = ["https://graph.microsoft.com/.default"]
+    # msal is untyped; construct the client and cast to our Protocol for type checking
+    app_untyped = ConfidentialClientApplication(
+        client_id, authority=authority, client_credential=client_secret
+    )
+    app: ConfidentialClientProtocol = cast(ConfidentialClientProtocol, app_untyped)
+
+    result = app.acquire_token_for_client(scopes=scope)
+    if not result:
+        raise Exception("Erro obtendo token: resposta vazia ou inválida do MSAL")
+
+    access_token = result.get("access_token")
+    if isinstance(access_token, str) and access_token:
+        return access_token
+    else:
+        raise Exception(f"Erro obtendo token: {result.get('error_description')}")
+
+
+def send_message_to_user(user_id: str, message_text: str):
+    token = get_access_token(TEAMS_CLIENT_ID, TEAMS_CLIENT_SECRET, TEAMS_TENANT_ID)
+    headers = {"Authorization": f"Bearer {token}", "Content-Type": "application/json"}
+
+    # Primeiro, criar ou obter chat com o usuário
+    create_chat_url = "https://graph.microsoft.com/v1.0/chats"
+    chat_payload: dict[str, Any] = {
+        "chatType": "oneOnOne",
+        "members": [
+            {
+                "@odata.type": "#microsoft.graph.aadUserConversationMember",
+                "roles": ["owner"],
+                "user@odata.bind": f"https://graph.microsoft.com/v1.0/users('{user_id}')",
+            },
+            {
+                "@odata.type": "#microsoft.graph.aadUserConversationMember",
+                "roles": ["owner"],
+                "user@odata.bind": f"https://graph.microsoft.com/v1.0/users('{user_id}')",
+            },
+        ],
+    }
+
+    chat_response = requests.post(create_chat_url, headers=headers, json=chat_payload)
+
+    if chat_response.status_code not in (200, 201):
+        raise Exception(
+            f"Erro criando chat: {chat_response.status_code} {chat_response.text}"
+        )
+
+    chat = chat_response.json()
+    chat_id = chat["id"]
+
+    # Agora, enviar mensagem no chat criado/obtido
+    send_message_url = f"https://graph.microsoft.com/v1.0/chats/{chat_id}/messages"
+    message_payload = {"body": {"content": message_text}}
+
+    message_response = requests.post(
+        send_message_url, headers=headers, json=message_payload
+    )
+
+    if message_response.status_code == 201:
+        print("Mensagem enviada com sucesso para o usuário!")
+        return message_response.json()
+    else:
+        raise Exception(
+            f"Erro enviando mensagem: {message_response.status_code} {message_response.text}"
+        )
+
+
+def get_version() -> str:
+    # find pyproject.toml in parent directories and read version from it
+    pyproject_dir = Path(__file__).parent.parent
+    pyproject_path = pyproject_dir / "pyproject.toml"
+    if pyproject_path.exists():
+        with open(pyproject_path, "r", encoding="utf-8") as f:
+            for line in f:
+                if line.startswith("version"):
+                    return line.split("=")[1].strip().strip('"')
+
+    return "<not found>"
+
+
 if __name__ == "__main__":
-    print(converter_data_siga("25"))
+    print(get_version())
